cmd

package
v2.8.22 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 12, 2026 License: Apache-2.0 Imports: 30 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute()

Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.

func ExportEntry

func ExportEntry(entry interface{}, outFile *os.File, extra map[string]string) (int, error)

func GotTestDir

func GotTestDir(t *testing.T, filename string) string

func MaybeUpload

func MaybeUpload(cloudCredentials, cloudStorageBucket, cloudProvider, path string)

func MustOutFile

func MustOutFile(path string) *os.File

func PrintTransformStats

func PrintTransformStats(attempts, failures int)

Prints the number of attempted, failed, and successful transformations as a JSON object

func RunCLITest

func RunCLITest(t *testing.T, test CliTest, GoldenFolder string, executableName string, useParentDir bool)

func WriteParquet

func WriteParquet(data []transform.SchemaParquet, path string, schema interface{})

WriteParquet creates the parquet file and writes the exported data into it.

Parameters:

data []transform.SchemaParquet  - The slice of data to be written to the Parquet file.
									SchemaParquet is an interface used to call ToParquet()
									which is defined for each schema/export.
path string                     - The file path where the Parquet file will be created and written.
									For example, "some/file/path/export_output.parquet"
schema interface{}              - The schema that defines the structure of the Parquet file.

Errors:

stellar-etl will log a Fatal error and stop in the case it cannot create or write to the parquet file

Types

type CliTest

type CliTest struct {
	Name              string
	Args              []string
	Golden            string
	WantErr           error
	SortForComparison bool
}

type CloudStorage

type CloudStorage interface {
	UploadTo(credentialsPath, bucket, path string) error
}

type GCS

type GCS struct {
	// contains filtered or unexported fields
}

func (*GCS) UploadTo

func (g *GCS) UploadTo(credentialsPath, bucket, path string) error

Jump to