Documentation
¶
Index ¶
- func Execute()
- func ExportEntry(entry interface{}, outFile *os.File, extra map[string]string) (int, error)
- func GotTestDir(t *testing.T, filename string) string
- func MaybeUpload(cloudCredentials, cloudStorageBucket, cloudProvider, path string)
- func MustOutFile(path string) *os.File
- func PrintTransformStats(attempts, failures int)
- func RunCLITest(t *testing.T, test CliTest, GoldenFolder string, executableName string, ...)
- func WriteParquet(data []transform.SchemaParquet, path string, schema interface{})
- type CliTest
- type CloudStorage
- type GCS
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Execute ¶
func Execute()
Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.
func ExportEntry ¶
func MaybeUpload ¶
func MaybeUpload(cloudCredentials, cloudStorageBucket, cloudProvider, path string)
func MustOutFile ¶
func PrintTransformStats ¶
func PrintTransformStats(attempts, failures int)
Prints the number of attempted, failed, and successful transformations as a JSON object
func RunCLITest ¶
func WriteParquet ¶
func WriteParquet(data []transform.SchemaParquet, path string, schema interface{})
WriteParquet creates the parquet file and writes the exported data into it.
Parameters:
data []transform.SchemaParquet - The slice of data to be written to the Parquet file.
SchemaParquet is an interface used to call ToParquet()
which is defined for each schema/export.
path string - The file path where the Parquet file will be created and written.
For example, "some/file/path/export_output.parquet"
schema interface{} - The schema that defines the structure of the Parquet file.
Errors:
stellar-etl will log a Fatal error and stop in the case it cannot create or write to the parquet file
Types ¶
type CloudStorage ¶
Source Files
¶
- command_utils.go
- export_assets.go
- export_contract_events.go
- export_effects.go
- export_ledger_entry_changes.go
- export_ledger_transaction.go
- export_ledgers.go
- export_operations.go
- export_token_transfers.go
- export_trades.go
- export_transactions.go
- get_ledger_range_from_times.go
- ledger_batch_export.go
- root.go
- test_utils.go
- upload_to_gcs.go
- version.go
Click to show internal directories.
Click to hide internal directories.